@@ -28,15 +28,15 @@
 
 
 from linshareapi.cache import Time
-from argtoolbox import DefaultCompleter as Completer
-from linsharecli.common.filters import PartialOr
 from linsharecli.admin.core import DefaultCommand
 from linsharecli.common.actions import CreateAction
 from linsharecli.common.actions import UpdateAction
 from linsharecli.common.core import add_list_parser_options
 from linsharecli.common.tables import DeleteAction
 from linsharecli.common.tables import TableBuilder
-from linsharecli.common.cell import ComplexCell
+from argtoolbox import DefaultCompleter as Completer
+from vhatable.cell import ComplexCell
+from vhatable.filters import PartialOr
 
 
 class DomainPoliciesCommand(DefaultCommand):
