@@ -28,13 +28,13 @@
 
 
 from linshareapi.cache import Time
+from argtoolbox import DefaultCompleter as Completer
+from vhatable.filters import PartialOr
 from linsharecli.common.core import add_list_parser_options
-from linsharecli.common.filters import PartialOr
 from linsharecli.admin.core import DefaultCommand
 from linsharecli.common.core import add_delete_parser_options
 from linsharecli.common.actions import CreateAction
 from linsharecli.common.tables import TableBuilder
-from argtoolbox import DefaultCompleter as Completer
 
 
 class DomainPatternsCommand(DefaultCommand):
