@@ -44,17 +44,14 @@ import json
 import getpass
 import datetime
 import locale
-import urllib.request, urllib.error, urllib.parse
-import types
+import urllib.error
 import copy
+from warnings import warn
 from argparse import ArgumentError
 from humanfriendly import format_size
-from linshareapi.core import LinShareException
-from linsharecli.common.tables import HTable
-from linsharecli.common.tables import VTable
-from linsharecli.common.tables import ConsoleTable
-import argtoolbox
 from argtoolbox import DefaultCompleter as Completer
+from argtoolbox import DefaultCommand as DefaultCommandArgtoolbox
+from linshareapi.core import LinShareException
 
 
 def hook_file_content(path, context):
@@ -64,11 +61,12 @@ def hook_file_content(path, context):
         return fde.read()
 
 
-class DefaultCommand(argtoolbox.DefaultCommand):
+class DefaultCommand(DefaultCommandArgtoolbox):
     """ If you want to add a new command to the command line interface, your
     class should extend this class.
     """
     # pylint: disable=line-too-long
+    # pylint: disable=too-many-public-methods
     IDENTIFIER = "name"
     DEFAULT_SORT = "creationDate"
     DEFAULT_TOTAL = "Ressources found : %(count)s"
@@ -90,12 +88,6 @@ class DefaultCommand(argtoolbox.DefaultCommand):
     CFG_DELETE_MODE = 0
     CFG_DELETE_ARG_ATTR = "parent_uuid"
 
-    ACTIONS = {
-        'delete' : '_delete_all',
-        'download' : '_download_all',
-        'count_only' : '_count_only',
-    }
-
     def __init__(self, config):
         super(DefaultCommand, self).__init__(config)
         self.api_version = config.server.api_version.value
@@ -103,7 +95,7 @@ class DefaultCommand(argtoolbox.DefaultCommand):
         self.log = logging.getLogger('linsharecli.' + classname)
         self.verbose = False
         self.debug = False
-        #pylint: disable=C0103
+        # pylint: disable=invalid-name
         self.ls = None
         self.enable_auth = True
 
@@ -144,6 +136,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             "You must implement the __get_cli_object method.")
 
     def _apply_to_all(self, args, cli, uuids, msg_m, func):
+        warn("This method is deprecated, use DownloadAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         count = len(uuids)
         position = 0
         res = 0
@@ -159,6 +154,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
         return True
 
     def _download_all(self, args, cli, uuids):
+        warn("This method is deprecated, use DownloadAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         count = len(uuids)
         position = 0
         res = 0
@@ -180,6 +178,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
         return True
 
     def _download(self, args, cli, uuid, position=None, count=None):
+        warn("This method is deprecated, use DownloadAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         directory = getattr(args, "directory", None)
         if directory:
             if not os.path.isdir(directory):
@@ -216,6 +217,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             return False
 
     def _download_with_parent(self, args, cli, uuid, position=None, count=None):
+        warn("This method is deprecated, use DownloadAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         directory = getattr(args, "directory", None)
         if directory:
             if not os.path.isdir(directory):
@@ -251,6 +255,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             return False
 
     def _download_folder_with_parent(self, args, cli, uuid, position=None, count=None):
+        warn("This method is deprecated, use DownloadAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         meta = {}
         meta['uuid'] = uuid
         meta['time'] = " -"
@@ -312,6 +319,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             return False
 
     def _delete_all(self, args, cli, uuids):
+        warn("This method is deprecated, use DeleteAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         count = len(uuids)
         position = 0
         res = 0
@@ -333,6 +343,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
         return True
 
     def _delete(self, args, cli, uuid, position=None, count=None):
+        warn("This method is deprecated, use DeleteAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         cli_mode = getattr(args, 'cli_mode', False)
         try:
             if not position:
@@ -364,6 +377,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             return False
 
     def _delete_with_parent(self, args, cli, uuid, position=None, count=None):
+        warn("This method is deprecated, use DeleteAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         try:
             if not position:
                 position = 1
@@ -393,6 +409,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             return False
 
     def _update(self, args, cli, resource, position=None, count=None):
+        warn("This method is deprecated, use TableAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         try:
             if not position:
                 position = 1
@@ -420,6 +439,9 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             return False
 
     def _run(self, method, message_ok, err_suffix, *args):
+        warn("This method is deprecated, use TableAction instead",
+             DeprecationWarning,
+             stacklevel=2)
         try:
             json_obj = method(*args)
             if self.debug:
@@ -427,7 +449,7 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             self.log.info(message_ok, json_obj)
             return True
         except LinShareException as ex:
-            self.log.debug("LinShareException : " + str(ex.args))
+            self.log.debug("LinShareException : %s", ex.args)
             self.log.error(ex.args[1] + " : " + err_suffix)
         return False
 
@@ -440,7 +462,7 @@ class DefaultCommand(argtoolbox.DefaultCommand):
     def pprint_warn(self, msg, meta={}):
         """TODO"""
         msg = "WARN: " + msg % meta
-        self.log.warn(msg)
+        self.log.warning(msg)
         print(msg)
 
     def pprint_error(self, msg, meta={}):
@@ -449,7 +471,7 @@ class DefaultCommand(argtoolbox.DefaultCommand):
         self.log.error(msg)
         print(msg)
 
-    #pylint: disable=R0201
+    # pylint: disable=no-self-use
     def pretty_json(self, obj):
         """Just a pretty printer for a json object."""
         print((json.dumps(obj, sort_keys=True, indent=2)))
@@ -517,15 +539,15 @@ class DefaultCommand(argtoolbox.DefaultCommand):
         """TODO"""
         if datatype[name] == int:
             return "{" + name + "!s:" + str(int(maxlength[name] *
-                                                  factor)) + suffix
-        elif datatype[name] == int:
+                                                factor)) + suffix
+        if datatype[name] == int:
             return "{" + name + "!s:" + str(int(maxlength[name] *
-                                                  factor)) + suffix
-        elif datatype[name] == bool:
+                                                factor)) + suffix
+        if datatype[name] == bool:
             return "{" + name + "!s:" + str(int(maxlength[name] *
-                                                  factor)) + suffix
+                                                factor)) + suffix
         return "{" + name + ":" + str(int(maxlength[name] *
-                                            factor)) + suffix
+                                          factor)) + suffix
 
     def print_fields(self, data):
         """TODO"""
@@ -614,87 +636,6 @@ class DefaultCommand(argtoolbox.DefaultCommand):
             self.print_list(json_obj, d_format, "Documents",
                             no_legend=no_legend)
 
-    def get_table(self, args, cli, first_column, in_keys=None, other_table=None):
-        """TODO"""
-        keys = []
-        args.vertical = getattr(args, "vertical", False)
-        if not args.vertical:
-            if getattr(args, "json", False):
-                args.vertical = True
-            elif getattr(args, "csv", False):
-                args.vertical = True
-            else:
-                for key in self.ACTIONS:
-                    if getattr(args, key, False):
-                        args.vertical = True
-        args.reverse = getattr(args, "reverse", False)
-        args.extended = getattr(args, "extended", False)
-        if in_keys:
-            keys += in_keys
-            if self.IDENTIFIER not in in_keys:
-                keys.insert(0, self.IDENTIFIER)
-        else:
-            keys = cli.get_rbu().get_keys(args.extended)
-        table = None
-        if args.vertical:
-            table = VTable(keys, debug=self.debug)
-        else:
-            if other_table:
-                table = ConsoleTable(keys, debug=self.debug)
-            else:
-                table = HTable(keys)
-                # styles
-                table.align[first_column] = "l"
-                table.padding_width = 1
-        table.debug = args.debug
-        table.no_cell = args.no_cell
-        table.vertical = args.vertical
-        table.sortby = None
-        table.reversesort = args.reverse
-        table.keys = keys
-        table.json = getattr(args, "json", False)
-        table.raw_json = getattr(args, "raw_json", False)
-        table.csv = getattr(args, "csv", False)
-        table.raw = getattr(args, "raw", False)
-        table._pref_start = getattr(args, "start", 0)
-        table._pref_end = getattr(args, "end", 0)
-        table._pref_limit = getattr(args, "limit", 0)
-        table._pref_no_csv_headers = getattr(args, "no_headers", True)
-        # just backup args into table
-        table.args = args
-        return table
-
-    def get_raw_table(self, args, cli, first_column, keys, other_table=None):
-        """TODO"""
-        # pylint: disable=unused-argument
-        args.reverse = getattr(args, "reverse", False)
-        args.extended = getattr(args, "extended", False)
-        table = None
-        if args.vertical:
-            table = VTable(keys, debug=self.debug)
-        else:
-            if other_table:
-                table = ConsoleTable(keys, debug=self.debug)
-            else:
-                table = HTable(keys)
-                # styles
-                table.align[first_column] = "l"
-                table.padding_width = 1
-        table.sortby = None
-        table.reversesort = args.reverse
-        table.keys = keys
-        table.json = getattr(args, "json", False)
-        table.raw_json = getattr(args, "raw_json", False)
-        table.csv = getattr(args, "csv", False)
-        table.raw = getattr(args, "raw", False)
-        table._pref_start = getattr(args, "start", 0)
-        table._pref_end = getattr(args, "end", 0)
-        table._pref_limit = getattr(args, "limit", 0)
-        table._pref_no_csv_headers = getattr(args, "no_headers", True)
-        # just backup args into table
-        table.args = args
-        return table
-
     def check_required_options(self, args, required_fields, options):
         """Check if at least one option is set among the required_fields list"""
         one_set = False
